import confirm from 'ant-design-vue/es/modal/confirm'
import notification from 'ant-design-vue/es/notification'
import { getLodop } from '@/libs/LodopFuncs'
import moment from 'moment'
// 打印控件
export const JGPrint = function(data, type, printerType){
  if (!data) {
    return
  }
  // 针式打印
  if (printerType == 'NEEDLE') {
    const LODOP = getLodop(document.getElementById('LODOP_OB'), document.getElementById('LODOP_EM'))
    console.log(LODOP)
    if (!LODOP) {
      confirm({
        title: '提示?',
        content: h => <div>打印控件未安装，请先下载并安装。安装完成后，刷新页面即可打印。</div>,
        okText: '立即下载',
        okType: 'danger',
        cancelText: '暂不打印',
        onOk () {
          window.open('http://www.lodop.net/demolist/CLodop_Setup_for_Win32NT.zip')
        }
      })
      return
    }
    const rx = /<body[^>]*>([\s\S]+?)<\/body>/i///
    let m = rx.exec(data)
    if (m) m = m[1]
    LODOP.SET_SHOW_MODE('HIDE_PAPER_BOARD', 1) //  隐藏底图上有模拟走纸板的条纹线
    LODOP.SET_PRINT_PAGESIZE(3, '2140', '60', '') // 这里3表示纵向打印且纸高“按内容的高度”；2140表示纸宽214.0mm；45表示页底空白4.5mm
    LODOP.ADD_PRINT_HTM("0","0","RightMargin:0.5cm","BottomMargin:0.5cm",m)
    // LODOP.ADD_PRINT_TABLE(0, 0, '100%', '100%', m)
    if (type == 'preview') {
      LODOP.PREVIEW()
    }
    if (type == 'print') {
      LODOP.PRINT()
    }
  } else {
    const url = window.URL.createObjectURL(new Blob([data], { type: 'application/pdf' }))
    document.getElementById('print').innerHTML = '<iframe id="printfsqd" name="printfsqd" src="' + url + '" hidden></iframe>'
    // 喷墨打印
    if (type == 'preview') { //  预览
      window.open(url)
    } else if (type == 'print') { //  打印
      window.frames['printfsqd'].focus()
      window.frames['printfsqd'].print()
    }
  }
}

// 导出下载excel
export const downloadExcel = function (data,fileName){
   if (!data) { return }
   const url = window.URL.createObjectURL(new Blob([data]))
   const link = document.createElement('a')
   link.style.display = 'none'
   link.href = url
   const a = moment().format('YYYYMMDDHHmmss')
   const fname = fileName + a
   link.setAttribute('download', fname + '.xlsx')
   document.body.appendChild(link)
   link.click()
}

/*
  *printerType: 打印机类型
  *type: 打印预览，打印，导出
  *url: 数据请求接口
  *params: 请求参数
  *fileName: 导出文件名称
  *callback: 回调函数
*/
export const hdPrint = function (printerType,type,url,params,fileName,callback){
  // 打印时需要传打印机类型
  if(type !== 'export'){
    params.type = printerType
  }
  url(params).then(res => {
    if (res.type == 'application/json') {
      var reader = new FileReader()
      reader.addEventListener('loadend', function () {
        const obj = JSON.parse(reader.result)
        notification.error({
          message: '提示',
          description: obj.message
        })
      })
      reader.readAsText(res)
    } else {
      if (type == 'export') { //  导出
        downloadExcel(res, fileName)
      } else { // 打印
        JGPrint(res, type, printerType)
      }
    }
    callback()
  })
}